@@ -1,20 +1,22 @@
 import xml.sax
+import re, urllib
 from os.path import join, expanduser, exists
 from gettext import gettext as _
 import gtk
-import deskbar, deskbar.indexer, deskbar.handler
-from deskbar.filewatcher import FileWatcher
-from deskbar.handlers_browsers import get_url_host, is_preferred_browser
-from deskbar.handlers_browsers import BrowserSmartMatch, BrowserMatch
+import gnomevfs
+import deskbar, deskbar.Indexer, deskbar.Handler
+from deskbar.Watcher import FileWatcher
+from deskbar.BrowserMatch import get_url_host, is_preferred_browser
+from deskbar.BrowserMatch import BrowserSmartMatch, BrowserMatch
 
 def _check_requirements():
-	if deskbar.UNINSTALLED_DESKBAR:
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+#	if deskbar.UNINSTALLED_DESKBAR:
+#		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 		
 	if is_preferred_browser("galeon"):
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	else:
-		return (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, "Galeon is not your preferred browser, not using it.", None)
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Galeon is not your preferred browser, not using it.", None)
 		
 HANDLERS = {
 	"GaleonBookmarksHandler" : {
@@ -31,19 +33,22 @@ HANDLERS = {
 		"name": _("Web Searches"),
 		"description": _("Search the web via your browser's search settings"),
 		"requirements": _check_requirements
-	}
+	},
 }
 
-GALEON_HISTORY_FILE = expanduser("~/.galeon/history.xml")
+GALEON_HISTORY_FILE = expanduser("~/.galeon/history2.xml")
+if not exists(GALEON_HISTORY_FILE):
+	GALEON_HISTORY_FILE = expanduser("~/.galeon/history.xml")
 GALEON_BOOKMARKS_FILE = expanduser("~/.galeon/bookmarks.xbel")
 
 favicon_cache = None
 bookmarks = None
 smart_bookmarks = None
+quicksearches = None
 
-class GaleonHandler(deskbar.handler.Handler):
-	def __init__(self, watched_file, callback):
-		deskbar.handler.Handler.__init__(self, "web-bookmark.png")
+class GaleonHandler(deskbar.Handler.Handler):
+	def __init__(self, watched_file, callback, icon="stock_bookmark"):
+		deskbar.Handler.Handler.__init__(self, icon)
 		self.watched_file = watched_file
 		self.watch_callback = callback
 		
@@ -71,27 +76,33 @@ class GaleonBookmarksHandler(GaleonHandler):
 		self._parse_bookmarks()
 	
 	def _parse_bookmarks(self, force=False):
-		global favicon_cache, bookmarks, smart_bookmarks
+		global favicon_cache, bookmarks, smart_bookmarks, quicksearches
 		if force or bookmarks == None:
 			parser = GaleonBookmarksParser(self, favicon_cache)
 			bookmarks = parser.get_indexer()
 			smart_bookmarks = parser.get_smart_bookmarks()
+			quicksearches = parser.get_quicksearches()
 	
-	def query(self, query, max=5):
+	def query(self, query):
 		global bookmarks
-		return bookmarks.look_up(query)[:max]
+		return bookmarks.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
 
 class GaleonSearchHandler(GaleonBookmarksHandler):
 	def __init__(self):
 		GaleonBookmarksHandler.__init__(self)
 	
-	def query(self, query, max=5):
+	def query(self, query):
 		global smart_bookmarks
-		return smart_bookmarks
+		global quicksearches
+		query_a = query.split(" ")
+		if len(query_a) > 1 and quicksearches.has_key(query_a[0]):
+			return (quicksearches[query_a[0]],)
+		else:
+			return smart_bookmarks
 		
 class GaleonHistoryHandler(GaleonHandler):
 	def __init__(self):
-		GaleonHandler.__init__(self, GALEON_HISTORY_FILE, self._parse_history)
+		GaleonHandler.__init__(self, GALEON_HISTORY_FILE, self._parse_history, "epiphany-history.png")
 		self._history = None
 		
 	def initialize(self):
@@ -102,8 +113,8 @@ class GaleonHistoryHandler(GaleonHandler):
 		global favicon_cache
 		self._history = GaleonHistoryParser(self, favicon_cache).get_indexer()
 			
-	def query(self, query, max=5):
-		return self._history.look_up(query)[:max]
+	def query(self, query):
+		return self._history.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
 
 class GaleonBookmarksParser(xml.sax.ContentHandler):
 	def __init__(self, handler, cache):
@@ -116,8 +127,10 @@ class GaleonBookmarksParser(xml.sax.ContentHandler):
 		self.href = None
 		self.smarthref = None
 		
-		self._indexer = deskbar.indexer.Index()
+		self._indexer = deskbar.Indexer.Indexer()
+		self._qsindexer = {}
 		self._smart_bookmarks = []
+
 		
 		self._cache = cache
 		self._index_bookmarks()
@@ -128,6 +141,9 @@ class GaleonBookmarksParser(xml.sax.ContentHandler):
 		"""
 		return self._indexer
 	
+	def get_quicksearches(self):
+		return self._qsindexer
+	
 	def get_smart_bookmarks(self):
 		"""
 		Return a list of GaleonSmartMatch instances representing smart bookmarks
@@ -149,30 +165,33 @@ class GaleonBookmarksParser(xml.sax.ContentHandler):
 			self.title = None
 			self.href = attrs['href'].encode('latin1')
 			self.smarthref = None
+			self.nick = None
 
 	def endElement(self, name):
 		if name == "title":
 			self.title = self.chars.encode('utf8')
 		elif name == "smarturl":
 			self.smarthref = self.chars.encode('latin1')
+			self.smarthref = re.sub('{.*}','',self.smarthref)
+		elif name == "nick":
+			self.nick = self.chars.encode('latin1')
 		elif name == "bookmark":
 			if self.href.startswith("javascript:"):
 				return
 			
-			pixbuf = None
-			try:
-				host = get_url_host(self.href)
-				if host in self._cache:
-					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(self._cache[host], deskbar.ICON_SIZE, deskbar.ICON_SIZE)
-			except Exception, msg:
-				# Most of the time we have an html page here, it could also be an unrecognized format
-				print 'Error:endElement(%s):Title:%s:%s' % (name.encode("utf8"), self.title, msg)
-			
-			bookmark = BrowserMatch(self.handler, self.title, self.href, pixbuf)
+			img = None
+			host = get_url_host(self.href)
+			if host in self._cache:
+				img = self._cache[host]
+
+			bookmark = BrowserMatch(self.handler, self.title, self.href, icon=img)
 			self._indexer.add("%s %s" % (self.title, self.href), bookmark)
+			if self.nick != None and self.smarthref != None:
+				quicksearch = BrowserSmartMatch(self.handler, self.title, self.smarthref, icon=img, bookmark=bookmark, prefix_to_strip=self.nick)
+				self._qsindexer[self.nick] = quicksearch
 
 			if self.smarthref != None:
-				bookmark = BrowserSmartMatch(bookmark, self.title, self.smarthref)
+				bookmark = BrowserSmartMatch(self.handler, self.title, self.smarthref, icon=img, bookmark=bookmark)
 				self._smart_bookmarks.append(bookmark)
 
 class GaleonFaviconCacheParser(xml.sax.ContentHandler):
@@ -227,7 +246,7 @@ class GaleonHistoryParser(xml.sax.ContentHandler):
 		self.handler = handler;
 		self._cache = cache;
 
-		self._indexer = deskbar.indexer.Index()
+		self._indexer = deskbar.Indexer.Indexer()
 
 		self._index_history();
 
@@ -253,12 +272,12 @@ class GaleonHistoryParser(xml.sax.ContentHandler):
 			try:
 				host = get_url_host(url)
 				if host in self._cache:
-					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(self._cache[host], deskbar.ICON_SIZE, deskbar.ICON_SIZE)
+					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(self._cache[host], deskbar.ICON_HEIGHT, deskbar.ICON_HEIGHT)
 			except Exception, msg:
 				# Most of the time we have an html page here, it could also be an unrecognized format
 				print 'Error:endElement(%s):Title:%s:%s' % (name.encode("utf8"), title, msg)
 
-			item = BrowserMatch(self.handler, title, url, pixbuf, True)
+			item = BrowserMatch(self.handler, title, url, True, icon=pixbuf)
 			self._indexer.add("%s %s" % (title, url), item)
 
 	def characters(self, chars):
