@@ -1,6 +1,7 @@
 import os, re, HTMLParser, base64, glob
 from os.path import join, expanduser, exists, basename
 from gettext import gettext as _
+from ConfigParser import RawConfigParser
 
 import gtk
 from deskbar.Watcher import FileWatcher, DirWatcher
@@ -31,16 +32,24 @@ def get_mozilla_home_file(needed_file):
 	
 def get_firefox_home_file(needed_file):
 	firefox_dir = expanduser("~/.mozilla/firefox/")
-	path_pattern = re.compile("^Path=(.*)")
-	for line in file(join(firefox_dir, "profiles.ini")):
-		match_obj = path_pattern.search(line)
-		if match_obj:
-			if match_obj.group(1).startswith("/"):
-				return join(match_obj.group(1), needed_file)
-			else:
-				return join(firefox_dir, match_obj.group(1), needed_file)
-				
-	return ""
+	config = RawConfigParser({"Default" : 0})
+	config.read(expanduser(join(firefox_dir, "profiles.ini")))
+	path = None
+
+	for section in config.sections():
+		if config.get (section, "Default") == 1:
+			path = config.get (section, "Path")
+			break
+		elif path == None and config.has_option(section, "Path"):
+			path = config.get (section, "Path")
+		
+	if path == None:
+		return ""
+
+	if path.startswith("/"):
+		return join(path, needed_file)
+
+	return join(firefox_dir, path, needed_file)
 
 # Whether we offer all of the browser's search engines, or only the primary
 # one (since by default Firefox seems to come with at least half a dozen)			
@@ -71,7 +80,7 @@ try:
 except:
 	pass
 
-def _on_handler_preferences():
+def _on_handler_preferences(dialog):
 	def toggled_cb(sender, show_all_radio, show_primary_radio):
 		deskbar.GCONF_CLIENT.set_bool(GCONF_SHOW_ONLY_PRIMARY_KEY, show_primary_radio.get_active())
 		
@@ -125,6 +134,11 @@ HANDLERS = {
 		"name": _("Web Searches"),
 		"description": _("Search the web via your browser's search settings"),
 		"requirements": _check_requirements_search
+	},
+	"MozillaHistoryHandler" : {
+		"name": _("Web History"),
+		"description": _("Open your web history by name"),
+		"requirements": _check_requirements_bookmarks
 	}
 }
 
@@ -533,3 +547,37 @@ class MozillaSmartBookmarksDirParser:
 		Return a list of MozillaSmartMatch instances representing smart bookmarks
 		"""
 		return self._smart_bookmarks
+
+MOZILLA_HISTORY_REGEX = re.compile("\=http[0-9a-zA-Z\-\&\%\=\?\:\/\.]*\)")
+class MozillaHistoryHandler(deskbar.Handler.Handler):
+	def __init__(self):
+		deskbar.Handler.Handler.__init__(self, "epiphany-history.png")
+		self._history = None
+	
+	def initialize(self):
+		self._indexer = deskbar.Indexer.Indexer()
+		self._history = self._parse_history()
+		for history_url in self._history:
+			history_wo_http = history_url[history_url.find('//')+2:]
+			if history_wo_http.find('www.') == -1:
+				history_wo_www = history_wo_http
+			else:
+				history_wo_www = history_wo_http[history_wo_http.find('www.')+4:]
+			self._indexer.add("%s %s %s" % (history_wo_www, history_wo_http, history_url), BrowserMatch(self, history_wo_www, history_url, True))
+		
+	def _parse_history(self):
+		if USING_FIREFOX:
+			historydat = get_firefox_home_file("history.dat")
+		else:
+			historydat = get_mozilla_home_file("history.dat")
+		try:
+			historycontents = file(historydat).read()
+			historycontents = re.findall(MOZILLA_HISTORY_REGEX, historycontents)
+			historycontents = [x[1:-1] for x in historycontents]
+			return historycontents
+		except:
+			return ""
+	
+	def query(self, query):
+		return self._indexer.look_up(query)[:deskbar.DEFAULT_RESULTS_PER_HANDLER]
+
